@@ -395,6 +395,35 @@ class RosZone(
     ) -> None:
         jsii.set(self, "remark", value)
 
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="resourceGroupId")
+    def resource_group_id(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''
+        :Property: resourceGroupId: Resource group id.
+        '''
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], jsii.get(self, "resourceGroupId"))
+
+    @resource_group_id.setter
+    def resource_group_id(
+        self,
+        value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]],
+    ) -> None:
+        jsii.set(self, "resourceGroupId", value)
+
+    @builtins.property # type: ignore[misc]
+    @jsii.member(jsii_name="tags")
+    def tags(self) -> typing.Optional[typing.List["RosZone.TagsProperty"]]:
+        '''
+        :Property: tags: Tags to attach to instance. Max support 20 tags to add during create instance. Each tag with two properties Key and Value, and Key is required.
+        '''
+        return typing.cast(typing.Optional[typing.List["RosZone.TagsProperty"]], jsii.get(self, "tags"))
+
+    @tags.setter
+    def tags(self, value: typing.Optional[typing.List["RosZone.TagsProperty"]]) -> None:
+        jsii.set(self, "tags", value)
+
     @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="zoneTag")
     def zone_tag(
@@ -429,6 +458,58 @@ class RosZone(
     ) -> None:
         jsii.set(self, "zoneType", value)
 
+    @jsii.data_type(
+        jsii_type="@alicloud/ros-cdk-pvtz.RosZone.TagsProperty",
+        jsii_struct_bases=[],
+        name_mapping={"key": "key", "value": "value"},
+    )
+    class TagsProperty:
+        def __init__(
+            self,
+            *,
+            key: typing.Union[builtins.str, ros_cdk_core.IResolvable],
+            value: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        ) -> None:
+            '''
+            :param key: 
+            :param value: 
+            '''
+            self._values: typing.Dict[str, typing.Any] = {
+                "key": key,
+            }
+            if value is not None:
+                self._values["value"] = value
+
+        @builtins.property
+        def key(self) -> typing.Union[builtins.str, ros_cdk_core.IResolvable]:
+            '''
+            :Property: key: undefined
+            '''
+            result = self._values.get("key")
+            assert result is not None, "Required property 'key' is missing"
+            return typing.cast(typing.Union[builtins.str, ros_cdk_core.IResolvable], result)
+
+        @builtins.property
+        def value(
+            self,
+        ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+            '''
+            :Property: value: undefined
+            '''
+            result = self._values.get("value")
+            return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+
+        def __eq__(self, rhs: typing.Any) -> builtins.bool:
+            return isinstance(rhs, self.__class__) and rhs._values == self._values
+
+        def __ne__(self, rhs: typing.Any) -> builtins.bool:
+            return not (rhs == self)
+
+        def __repr__(self) -> str:
+            return "TagsProperty(%s)" % ", ".join(
+                k + "=" + repr(v) for k, v in self._values.items()
+            )
+
 
 @jsii.data_type(
     jsii_type="@alicloud/ros-cdk-pvtz.RosZoneProps",
@@ -437,6 +518,8 @@ class RosZone(
         "zone_name": "zoneName",
         "proxy_pattern": "proxyPattern",
         "remark": "remark",
+        "resource_group_id": "resourceGroupId",
+        "tags": "tags",
         "zone_tag": "zoneTag",
         "zone_type": "zoneType",
     },
@@ -448,6 +531,8 @@ class RosZoneProps:
         zone_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
         proxy_pattern: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         remark: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        tags: typing.Optional[typing.Sequence[RosZone.TagsProperty]] = None,
         zone_tag: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         zone_type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
     ) -> None:
@@ -456,6 +541,8 @@ class RosZoneProps:
         :param zone_name: 
         :param proxy_pattern: 
         :param remark: 
+        :param resource_group_id: 
+        :param tags: 
         :param zone_tag: 
         :param zone_type: 
         '''
@@ -466,6 +553,10 @@ class RosZoneProps:
             self._values["proxy_pattern"] = proxy_pattern
         if remark is not None:
             self._values["remark"] = remark
+        if resource_group_id is not None:
+            self._values["resource_group_id"] = resource_group_id
+        if tags is not None:
+            self._values["tags"] = tags
         if zone_tag is not None:
             self._values["zone_tag"] = zone_tag
         if zone_type is not None:
@@ -504,6 +595,24 @@ class RosZoneProps:
         result = self._values.get("remark")
         return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
 
+    @builtins.property
+    def resource_group_id(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''
+        :Property: resourceGroupId: Resource group id.
+        '''
+        result = self._values.get("resource_group_id")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+
+    @builtins.property
+    def tags(self) -> typing.Optional[typing.List[RosZone.TagsProperty]]:
+        '''
+        :Property: tags: Tags to attach to instance. Max support 20 tags to add during create instance. Each tag with two properties Key and Value, and Key is required.
+        '''
+        result = self._values.get("tags")
+        return typing.cast(typing.Optional[typing.List[RosZone.TagsProperty]], result)
+
     @builtins.property
     def zone_tag(
         self,
@@ -1234,6 +1343,8 @@ class Zone(
         "zone_name": "zoneName",
         "proxy_pattern": "proxyPattern",
         "remark": "remark",
+        "resource_group_id": "resourceGroupId",
+        "tags": "tags",
         "zone_tag": "zoneTag",
         "zone_type": "zoneType",
     },
@@ -1245,6 +1356,8 @@ class ZoneProps:
         zone_name: typing.Union[builtins.str, ros_cdk_core.IResolvable],
         proxy_pattern: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         remark: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        resource_group_id: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
+        tags: typing.Optional[typing.Sequence[RosZone.TagsProperty]] = None,
         zone_tag: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
         zone_type: typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]] = None,
     ) -> None:
@@ -1253,6 +1366,8 @@ class ZoneProps:
         :param zone_name: Property zoneName: Zone name.
         :param proxy_pattern: Property proxyPattern: ZONE: completely hijack the entire zone. RECORD: Incomplete hijacking, recursive resolution agent. Default to ZONE.
         :param remark: Property remark: 50 characters at most. It can only contain numbers, Chinese, English and special characters: "_-,.，。".
+        :param resource_group_id: Property resourceGroupId: Resource group id.
+        :param tags: Property tags: Tags to attach to instance. Max support 20 tags to add during create instance. Each tag with two properties Key and Value, and Key is required.
         :param zone_tag: Property zoneTag: Zone label. It will be ignored when ZoneType is AUTH_ZONE.
         :param zone_type: Property zoneType: Zone type. For instance: AUTH_ZONE, CLOUD_PRODUCT_ZONE.
         '''
@@ -1263,6 +1378,10 @@ class ZoneProps:
             self._values["proxy_pattern"] = proxy_pattern
         if remark is not None:
             self._values["remark"] = remark
+        if resource_group_id is not None:
+            self._values["resource_group_id"] = resource_group_id
+        if tags is not None:
+            self._values["tags"] = tags
         if zone_tag is not None:
             self._values["zone_tag"] = zone_tag
         if zone_type is not None:
@@ -1298,6 +1417,23 @@ class ZoneProps:
         result = self._values.get("remark")
         return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
 
+    @builtins.property
+    def resource_group_id(
+        self,
+    ) -> typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]]:
+        '''Property resourceGroupId: Resource group id.'''
+        result = self._values.get("resource_group_id")
+        return typing.cast(typing.Optional[typing.Union[builtins.str, ros_cdk_core.IResolvable]], result)
+
+    @builtins.property
+    def tags(self) -> typing.Optional[typing.List[RosZone.TagsProperty]]:
+        '''Property tags: Tags to attach to instance.
+
+        Max support 20 tags to add during create instance. Each tag with two properties Key and Value, and Key is required.
+        '''
+        result = self._values.get("tags")
+        return typing.cast(typing.Optional[typing.List[RosZone.TagsProperty]], result)
+
     @builtins.property
     def zone_tag(
         self,
